import {FC, useCallback, useEffect, useState} from "react";
import {Image, View} from "@tarojs/components";
import {brandApi, BrandRecord} from "@/api";
import styles from './list.module.scss'
import Taro, {useReachBottom} from "@tarojs/taro";
import Empty from "@/components/empty/empty";
import Collapse from "@/components/collapse/collapse";
import {illnessApi} from "@/api/illness";
import {apis} from "@tarojs/plugin-platform-h5/dist/dist/definition.json";
import setNavigationBarTitle = apis.setNavigationBarTitle;

const BrandList: FC = () => {
  const [page, setPage] = useState(1)
  const [brands, setBrands] = useState<any[]>([])
  const [total, setTotal] = useState(0)

  useEffect(() => {
    getData()
  }, [page])

  const getData = useCallback(async () => {
    try {
      const data = await illnessApi.list(22,1, 100)
      setTotal(data.total)
      setBrands([
        ...data.list
      ])
      Taro.setNavigationBarTitle({title: data.list?.[0].resourceCategories?.[0]?.name ?? '文章列表'})
    } catch (e) {
    }
  }, [page])


  useReachBottom(useCallback(() => {
    if (brands?.length < total) {
      setPage(page + 1)
    }
  }, [total, brands]))


  return (
    <View className='p-2'>
      {
            brands.length &&
            brands.map((d) =>
              <View  className={styles.box} >
                <View className={styles.rightBox}>
                  <Collapse title={d.name} children={
                    <>
                      {
                        d.articles?.map((d) =>
                          <View onClick={() => {Taro.navigateTo({url: `/pages/preview/illness/article/article?id=${d.id}`})}} className='mt-2 font-28 ml-5'>{d.title}</View>

                        )
                      }
                    </>
                  }></Collapse>
                </View>
              </View>
            )
      }
    </View>
  )
}

export default BrandList
